ImportError

Enum ImportError 

pub enum ImportError {
    Empty(PathBuf),
    Meta(MetaError),
    MusicBrainz(MbError),
    Discogs(DiscogsError),
    Io(Error),
    Path(PathError),
    Conflict(String),
    Exists(PathBuf),
    Untagged(String),
}

Variants



Empty(PathBuf)



Meta(MetaError)



MusicBrainz(MbError)



Discogs(DiscogsError)



Io(Error)



Path(PathError)



Conflict(String)



Exists(PathBuf)

The album is already filed at this directory: its destinations are taken, by files not close enough to these to be the same copy. Filed by the same rules into the same format’s folder, it is the same album.



Untagged(String)

The files’ own tags do not describe one album well enough to file it by them.

Implementations

Source

impl ImportError

pub fn is_transient(&self) -> bool

Whether the same import could succeed later without anything changing here.